To use (with caution), simply do:

    >>> import resqlconnection
    >>> conn = resqlconnection.ReSqlConnection(server_name,db_name)
    >>> conn.get_all_tables() #see example_of_use.py for more


# https://python-packaging.readthedocs.io/en/latest/minimal.html
